[openssh-commits] [openssh] branch master updated: Use clang-20 when building hardenedmalloc for tests.

git+noreply at mindrot.org git+noreply at mindrot.org
Sat Aug 8 21:23:43 AEST 2026


This is an automated email from the git hooks/post-receive script.

dtucker pushed a commit to branch master
in repository openssh.

The following commit(s) were added to refs/heads/master by this push:
     new 64ede7991 Use clang-20 when building hardenedmalloc for tests.
64ede7991 is described below

commit 64ede7991d9e2021d84fb3eb89ed1dd1c2a1179e
Author: Darren Tucker <dtucker at dtucker.net>
AuthorDate: Sat Aug 8 21:14:57 2026 +1000

    Use clang-20 when building hardenedmalloc for tests.
    
    Some versions of clang-19 report:
    error: invalid feature combination:  +avx10.1-256; will be promoted to
    avx10.1-512 [-Werror,-Winvalid-feature-combination]
---
 .github/setup_ci.sh | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/.github/setup_ci.sh b/.github/setup_ci.sh
index 2572a2882..8cbe9fd42 100755
--- a/.github/setup_ci.sh
+++ b/.github/setup_ci.sh
@@ -147,8 +147,8 @@ for TARGET in $TARGETS; do
 	;;
     hardenedmalloc)
 	INSTALL_HARDENED_MALLOC=yes
-	# Need clang >= 19 for constexpr.
-	PACKAGES="$PACKAGES clang-19"
+	# Need clang >= 19 for constexpr and >= 20 for avx10.1-512
+	PACKAGES="$PACKAGES clang-20"
 	;;
     musl)
 	PACKAGES="$PACKAGES musl-tools"
@@ -243,7 +243,8 @@ if [ "${INSTALL_HARDENED_MALLOC}" = "yes" ]; then
     (cd ${HOME} &&
      git clone https://github.com/GrapheneOS/hardened_malloc.git &&
      cd ${HOME}/hardened_malloc &&
-     make CC=clang-19 && sudo cp out/libhardened_malloc.so /usr/lib/)
+     clang-20 --version &&
+     make CC=clang-20 && sudo cp out/libhardened_malloc.so /usr/lib/)
 fi
 
 if [ ! -z "${INSTALL_OPENSSL}" ]; then

-- 
To stop receiving notification emails like this one, please contact
djm at mindrot.org.


More information about the openssh-commits mailing list